@@ -5,12 +5,17 @@ from pathlib import Path
 
 
 def login_args_configuration(sub_parser):
-    login_parser = sub_parser.add_parser(
-        name="login", help="login to deepchain")
+    """
+    Login subparser that add the default login function to the parser
+    """
+    login_parser = sub_parser.add_parser(name="login", help="login to deepchain")
     login_parser.set_defaults(func=login)
 
 
-def login(_):
+def login():
+    """
+    Login function that create a subdirectory and store the token
+    """
     path = Path.home().joinpath(".deep-chain")
     path.mkdir(exist_ok=True)
     path = path.joinpath("config")
