@@ -7,9 +7,12 @@ from .scaffold import scaffold_args_configuration
 
 
 def init_argparse() -> argparse.ArgumentParser:
-    main_parser = argparse.ArgumentParser(
-        description='deepchain cli', add_help=True)
+    """
+    Initalialisation of main parser and subparser for each function
+    """
+    main_parser = argparse.ArgumentParser(description="deepchain cli", add_help=True)
     sub_parser = main_parser.add_subparsers()
+
     login_args_configuration(sub_parser)
     scaffold_args_configuration(sub_parser)
     deploy_args_configuration(sub_parser)
@@ -23,5 +26,5 @@ def main():
     args.func(args)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
